@@ -41,18 +41,24 @@ CouchdbDatabaseInfo *couchdb_database_info_ref (CouchdbDatabaseInfo *dbinfo);
 void                 couchdb_database_info_unref (CouchdbDatabaseInfo *dbinfo);
 
 const char          *couchdb_database_info_get_dbname (CouchdbDatabaseInfo *dbinfo);
-gint                 couchdb_database_info_get_documents_count (CouchdbDatabaseInfo *dbinfo);
 gint                 couchdb_database_info_get_deleted_documents_count (CouchdbDatabaseInfo *dbinfo);
+gint                 couchdb_database_info_get_disk_format_version (CouchdbDatabaseInfo *dbinfo);
+gint                 couchdb_database_info_get_disk_size (CouchdbDatabaseInfo *dbinfo);
+gint                 couchdb_database_info_get_documents_count (CouchdbDatabaseInfo *dbinfo);
+gint                 couchdb_database_info_get_instance_start_time (CouchdbDatabaseInfo *dbinfo);
+gint                 couchdb_database_info_get_purge_sequence (CouchdbDatabaseInfo *dbinfo);
 gint                 couchdb_database_info_get_update_sequence (CouchdbDatabaseInfo *dbinfo);
 gboolean             couchdb_database_info_is_compact_running (CouchdbDatabaseInfo *dbinfo);
-gint                 couchdb_database_info_get_disk_size (CouchdbDatabaseInfo *dbinfo);
 
 CouchdbDatabaseInfo*	couchdb_database_info_new (const char *dbname,
 						   gint doc_count,
 						   gint doc_del_count,
 						   gint update_seq,
+						   gint purse_seq,
 						   gboolean compact_running,
-						   gint disk_size);
+						   gint disk_size,
+						   gint disk_format_version,
+						   gint instance_start_time);
 
 G_END_DECLS
 
